@@ -1,7 +1,7 @@
-from .version import VERSION as __version__
-del version
 from .calibration import *
 from .operators import *
 from .instrument import *
-from .configuration import *
+from .acquisition import *
 from .pointings import *
+
+__version__ = '2.4'
